% TEMPLATECOAX Template configuration file for Coaxial rotors simulations with Rotare.
%  This file extends the regular template configuration by adding N-1 coaxial rotors.
% -----
%
% See also: template, rotare, validconfig.
%
% <a href="https://gitlab.uliege.be/rotare/documentation">Complete documentation (online)</a>

% --------------------------------------------------------------------------------------------------
% (c) Copyright 2022-2023 University of Liege
% Author: Thomas Lambert <t.lambert@uliege.be>
% ULiege - Aeroelasticity and Experimental Aerodynamics
% MIT License
% Repo: https://gitlab.uliege.be/rotare/rotare
% Docs: https://gitlab.uliege.be/rotare/documentation
% Issues: https://gitlab.uliege.be/rotare/rotare/-/issues
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

N_ROTORS = 2; % Total number of rotors in coaxial configuration, [-]

% ==================================================================================================
% ================================== Baseline configuration ========================================
% ==================================================================================================
% Just load exisiting template
template;

Sim.Out.show3D = false; % Disable 3D as it is not supported for coaxial (yet)

% ==================================================================================================
% ====================================== COAXIAL SYSTEM  ===========================================
% ==================================================================================================
% Adds a as many rotors as required, based on the initial blade geometry

% First rotor settings for collective and RPM
init_coll = Op.collective;
init_rpm = Op.rpm;
Blade(N_ROTORS - 1) = Blade(1); % Pre-alloc

for i = 2:N_ROTORS

    % ================================ Blade and rotor geometry ====================================
    Blade(i) = Blade(1); % Make second rotor identical to first one
    Blade(i).spinDir = -1 * Blade(i - 1).spinDir; % Invert spin direction for each rotor
    Blade(i).nElem = round(Blade(i - 1).nElem * 1);

    % Shift second rotor w.r.t the application type
    if strcmp(Sim.Misc.appli, 'heli')
        rotorShift = [0, 0, -1] * Blade(i - 1).radius(end);
    else
        rotorShift = [-1, 0, 0] * Blade(i - 1).radius(end);
    end
    Blade(i).hubPos = Blade(i - 1).hubPos + rotorShift;

    % =================================== Operating points =========================================
    Op.collective = [Op.collective; init_coll + 5];
    Op.rpm = [Op.rpm; init_rpm * 1.5];
end
